@@ -3,7 +3,7 @@ c       make table for length <--> thickness convertion
 c      so that 1 dim. calc. be  faster.
 c  Actually this one is used only for making table.  see cl2tTA.f 
 c
-      subroutine cl2tTbl(h1, h2, cosz, step,
+      subroutine cl2tTbl(h1, h2, cosz1, cosz2, step,
      *  lengtb, htb, costb,  thicktb,  maxsize, tblsize)
 c
 
@@ -15,7 +15,8 @@ c        step, 2*step, ... along  the path
       real*8 h1  ! input.  higher vertical height in m
       real*8 h2   ! input.  lower vertical height in m
 c                  h1=30d3, h2=-0.1d3 would be standard.
-      real*8 cosz  ! input.  cos of zenith angle at h1
+      real*8 cosz1  ! input.  cos of zenith angle at h1
+      real*8 cosz2  ! input.  cos of zeniht angle at h2
       real*8 step  ! input.  step of the length from h1 to h2
       integer maxsize  ! input. max usable size of lengtb, and thicktb
       real*8  lengtb(maxsize) ! outpu. lengtb(i) = (i-1)*step
@@ -38,7 +39,7 @@ c      write(*,*) ' h1=',h1,' h2=',h2, ' cosz=',cosz,
 c     *    ' step=',step, ' maxsize=',maxsize
 c //////////
 
-      cost= cosz
+      cost= cosz1
       sumt = 0.
       lengtb(1) = 0.
       thicktb(1) = 0.
@@ -51,12 +52,12 @@ c //////////
 c //////////
 c          write(*, *) lengtb(i), thicktb(i), z, cost
 c///////////////
-         temp= cnewcos(z+Eradius, cost, step)
+         temp= max(cosz2, cnewcos(z+Eradius, cost, step))
          z = cnewh(z+Eradius, cost, step) - Eradius
          htb(i) = z
          cost = temp
          costb(i) = cost
-         if(z .le. h2 .or. cost .le.0.) then
+         if(z .le. h2) then
             tblsize = i
             goto 100
          endif
