@@ -36,7 +36,7 @@ c	(->  ---------------------------------------------
         real*8  Eta2Pi0 !2  eta/pi0 ratio. this is used to see the effect due to non-decay of pi0
                       ! at very high energies. Only soruce of h.e gamma can be eta and LPM may work
                       ! for them. default is 0.2
-        integer MulLow !2 if 1, QCD predicted multiplicity low is used in the adhoc model else UA5
+        integer MulLow !2 if 1, QCD predicted multiplicity law is used in the adhoc model else UA5
                        !  parametalization is used. Default is 0. 
                        !  0.6135exp(23/18sqrt(2log(roots/0.3))) is QCD jet prediction. 
                        !  7.2roots**0.254 -7 is UA5 data. The branch point is set at roots = 900 GeV. 
