@@ -19,7 +19,10 @@ c         in MovedTrack. If it is too large, path is truncated. Also compute
 c         deflection.
 c
        if(TrackBefMove.p.charge .ne. 0) then
-          call cputEnergyLoss
+          if(.not. (mod(HowGeomag, 10) .eq. 1 .and.
+     *                Zfirst .eq. 0.)) then
+             call cputEnergyLoss
+          endif
           if(MoveStat .ne. Dead) then
              call cputDeflection
           endif
